
# This file was generated by 'versioneer.py' (0.29) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2026-05-04T09:19:35+1000",
 "dirty": false,
 "error": null,
 "full-revisionid": "ffbcff2e46b8ed0e1fbd16d1d34006d7c57f2676",
 "version": "1.2.6b"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
